Uses search terms to find data related to torrents and has a cli to download highest seeded torrent

Examples of use:

n = nyaascrape("Gundam Wing")

n.main()

#finds best magnet link based on seeds

Example2:

n = nyaascrape("Escaflowne")

n.nyaadata()

#returns a tuple of data organized into dicts